from flask import request
from flask_restx import Resource, Namespace, reqparse

from app.defines import StatesCode

ns = Namespace('organization', description='组织管理接口')


@ns.route('/organization_list')
class OrganizationListApi(Resource):
    # @ns.doc(id='get_organization_list', description='获取组织列表')
    @ns.doc(id='get_corporation_list', description='获取公司列表')
    @ns.expect()
    def get(self):
        """获取组织列表"""
        data = [
            {"name": "中讯邮电咨询设计院有限公司", "code": 4032, "corporate": "张三", "contacts": "张三",
             "mobile": "13912345678"},
            {"name": "北京电信设计院有限公司", "code": 9417, "corporate": "李四", "contacts": "李四",
             "mobile": "13912345670"}
        ]
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": data}


@ns.route('/organization')
class OrganizationApi(Resource):
    @ns.doc(id='get_organization', description='查询公司')
    @ns.expect()
    def get(self):
        """查询公司"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": '查询'}

    @ns.doc(id='add_organization', description='新增公司')
    @ns.expect()
    def post(self):
        """新增公司"""

        return {"code": StatesCode.SUCCESS, "message": "成功", "data": '新增公司'}

    @ns.doc(id='delete_organization', description='新增公司')
    @ns.expect()
    def delete(self):
        """删除公司"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": '删除公司'}


@ns.route('/organization_details')
class OrganizationDetailsApi(Resource):

    @ns.doc(id='get_organization_details', description='获取公司详情')
    @ns.expect()
    def get(self):
        """获取organization组织详情"""

        data = {
            "full_name": "北京电信规划设计院有限公司",
            "for_short": "北京规划院",
            "superior_company": "中讯邮电咨询设计有限公司",
            "credit_code": 9111111111,
            "registered_address": "北京海淀区首体南路9号",
            "business_address": "北京海淀区首体南路9号",
            "corporate": "张三",
            "company_code": 11111,
            "authorized_strength": 222,
            "staff_num": 100,
        }
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": data}

    @ns.doc(id='update_organization_details', description='修改公司详情')
    @ns.expect()
    def put(self):
        """更新organization组织详情"""

        return {"code": StatesCode.SUCCESS, "message": "成功", "data": '修改公司详情'}


@ns.route('/department')
class DepartmentApi(Resource):

    @ns.doc(id='add_department', description='新增部门')
    @ns.expect()
    def post(self):
        """新增部门"""

        return {"code": StatesCode.SUCCESS, "message": "成功", "data": '新增部门'}

    @ns.doc(id='delete_organization_details', description='删除部门')
    @ns.expect()
    def delete(self):
        """删除部门"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": '删除部门'}


@ns.route('/department_details')
class DepartmentDetailsApi(Resource):

    @ns.doc(id='get_department_details', description='获取部门详情')
    @ns.expect()
    def get(self):
        """获取department部门详情"""

        data = {
            "iclass": "1",
            "parent_business": "智慧城市设计院",
            "department": "智慧楼宇BU",
            "principal": "张三",
            "liaison_officer": "李四",
            "duplicate_name": "z-智慧楼宇BU",
            "staff_num": 100,
            "freelance_staff": 100,
            "collaborative_work": 100,
            "etw": 100,
            "duties": "中讯邮电咨询设计有限公司"

        }
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": data}

    @ns.doc(id='update_organization_details', description='修改部门详情')
    @ns.expect()
    def put(self):
        """更新department部门详情"""

        return {"code": StatesCode.SUCCESS, "message": "成功", "data": '修改部门详情'}


@ns.route('/batch_delete_organization')
class BatchDeleteOrganizationApi(Resource):
    @ns.doc(id='batch_delete_users', description='批量删除公司')
    @ns.expect()
    def delete(self):
        """批量删除公司"""

        return {"code": StatesCode.SUCCESS, "message": "成功", "data": "user004"}
